@@ -54,31 +54,48 @@ void DealerInfoList::add(DealerInfo *dealer)
 
 Dealer *Dealer::s_instance = 0;
 
+
 Dealer::Dealer( KMainWindow* _parent , const char* _name )
-    : QCanvasView( 0, _parent, _name ), towait(0), myActions(0),
-ademo(0), ahint(0), aredeal(0),
-      takeTargets(false), _won(false), _waiting(0), stop_demo_next(false), _autodrop(true), moves(0)
+  : QCanvasView( 0, _parent, _name ),
+    towait(0),
+    myActions(0),
+    ademo(0),
+    ahint(0), 
+    aredeal(0),
+    takeTargets(false),
+    _won(false),
+    _waiting(0),
+    stop_demo_next(false),
+    _autodrop(true),
+    _gameRecorded(false)
 {
     setResizePolicy(QScrollView::Manual);
     setVScrollBarMode(AlwaysOff);
     setHScrollBarMode(AlwaysOff);
+
     setGameNumber(kapp->random());
     myCanvas.setAdvancePeriod(30);
     // myCanvas.setBackgroundColor( darkGreen );
     setCanvas(&myCanvas);
     myCanvas.setDoubleBuffering(true);
+
     undoList.setAutoDelete(true);
+
     demotimer = new QTimer(this);
+
     connect(demotimer, SIGNAL(timeout()), SLOT(demo()));
+
     assert(!s_instance);
     s_instance = this;
 }
 
+
 const Dealer *Dealer::instance()
 {
     return s_instance;
 }
 
+
 void Dealer::setBackgroundPixmap(const QPixmap &background, const QColor &midcolor)
 {
     _midcolor = midcolor;
@@ -142,6 +159,10 @@ KMainWindow *Dealer::parent() const
     return dynamic_cast<KMainWindow*>(QCanvasView::parent());
 }
 
+
+// ----------------------------------------------------------------
+
+
 void Dealer::hint()
 {
     unmarkAll();
@@ -153,6 +174,7 @@ void Dealer::hint()
     canvas()->update();
 }
 
+
 void Dealer::getHints()
 {
     for (PileList::Iterator it = piles.begin(); it != piles.end(); ++it)
@@ -325,7 +347,7 @@ void Dealer::contentsMousePressEvent(QMouseEvent* e)
             Card *c = dynamic_cast<Card*>(list.first());
             assert(c);
             CardList mycards = c->source()->cardPressed(c);
-            for (CardList::Iterator it = mycards.begin(); it != mycards.end(); ++it)
+            for (CardList::Iterator it = mycards.begin(); it != mycards.end(); ++it) 
                 (*it)->setAnimated(false);
             movingCards = mycards;
             moving_start = e->pos();
@@ -371,7 +393,9 @@ void Dealer::contentsMouseReleaseEvent( QMouseEvent *e)
             Card *c = dynamic_cast<Card*>(*it);
             assert(c);
             if (!c->animated()) {
-                cardClicked(c);
+                if ( cardClicked(c) ) {
+                    countGame();
+                }
                 takeState();
                 canvas()->update();
             }
@@ -467,9 +491,8 @@ void Dealer::contentsMouseReleaseEvent( QMouseEvent *e)
                 best = it;
             }
         }
+        countGame();
         c->source()->moveCards(movingCards, (*best).source);
-        ++moves;
-        emit setMoves( moves );
         takeState();
     }
     movingCards.clear();
@@ -496,7 +519,9 @@ void Dealer::contentsMouseDoubleClickEvent( QMouseEvent*e )
     Card *c = dynamic_cast<Card*>(*it);
     assert(c);
     if (!c->animated()) {
-        cardDblClicked(c);
+        if ( cardDblClicked(c) ) {
+            countGame();
+        }
         takeState();
     }
 }
@@ -570,8 +595,6 @@ bool Dealer::cardDblClicked(Card *c)
             CardList empty;
             empty.append(c);
             c->source()->moveCards(empty, tgt);
-            ++moves;
-            emit setMoves( moves );
             canvas()->update();
             return true;
         }
@@ -593,6 +616,7 @@ void Dealer::startNew()
     minsize = QSize(0,0);
     _won = false;
     _waiting = 0;
+    _gameRecorded=false;
     kdDebug(11111) << "startNew stopDemo\n";
     stopDemo();
     kdDebug(11111) << "startNew unmarkAll\n";
@@ -609,6 +633,7 @@ void Dealer::startNew()
 
     undoList.clear();
     emit undoPossible(false);
+    emit updateMoves();
     kdDebug(11111) << "startNew restart\n";
     restart();
     takeState();
@@ -620,14 +645,7 @@ void Dealer::startNew()
                 break;
         }
     }
-	 // count started game
-	 { // wrap in own scope to make KConfigGroupSave work
-    KConfig *config = kapp->config();
-    KConfigGroupSaver kcs(config, scores_group);
-	 unsigned int Total = config->readUnsignedNumEntry(QString("total%1").arg(_id),0);
-	 ++Total;
-	 config->writeEntry(QString("total%1").arg(_id),Total);
-	 }
+
     kdDebug(11111) << "startNew takeState\n";
     if (!towait)
         takeState();
@@ -685,7 +703,7 @@ public:
                 && source_index == rhs.source_index && tookdown == rhs.tookdown);
     }
     void fillNode(QDomElement &e) const {
-        e.setAttribute("value", it->value());
+        e.setAttribute("value", it->rank());
         e.setAttribute("suit", it->suit());
         e.setAttribute("source", source->index());
         e.setAttribute("x", x);
@@ -783,6 +801,7 @@ void Dealer::takeState()
     State *n = getState();
 
     if (!undoList.count()) {
+        emit updateMoves();
         undoList.append(n);
     } else {
         State *old = undoList.last();
@@ -791,6 +810,7 @@ void Dealer::takeState()
             delete n;
             n = 0;
         } else {
+            emit updateMoves();
             undoList.append(n);
         }
     }
@@ -826,7 +846,7 @@ void Dealer::saveGame(QDomDocument &doc) {
     QString data = getGameState();
     if (!data.isEmpty())
         dealer.setAttribute("data", data);
-    dealer.setAttribute("moves", QString::number(moves));
+    dealer.setAttribute("moves", QString::number(getMoves()));
 
     bool taken[1000];
     memset(taken, 0, sizeof(taken));
@@ -853,7 +873,7 @@ void Dealer::saveGame(QDomDocument &doc) {
             {
                 QDomElement card = doc.createElement("card");
                 card.setAttribute("suit", (*it)->suit());
-                card.setAttribute("value", (*it)->value());
+                card.setAttribute("value", (*it)->rank());
                 card.setAttribute("faceup", (*it)->isFaceUp());
                 card.setAttribute("x", (*it)->realX());
                 card.setAttribute("y", (*it)->realY());
@@ -926,13 +946,13 @@ void Dealer::openGame(QDomDocument &doc)
                     for (uint j = 0; j < pcards.count(); ++j)
                     {
                         QDomElement card = pcards.item(j).toElement();
-                        Card::Suits s = static_cast<Card::Suits>(card.attribute("suit").toInt());
-                        Card::Values v = static_cast<Card::Values>(card.attribute("value").toInt());
+                        Card::Suit s = static_cast<Card::Suit>(card.attribute("suit").toInt());
+                        Card::Rank v = static_cast<Card::Rank>(card.attribute("value").toInt());
 
                         for (CardList::Iterator it2 = cards.begin();
                              it2 != cards.end(); ++it2)
                         {
-                            if ((*it2)->suit() == s && (*it2)->value() == v) {
+                            if ((*it2)->suit() == s && (*it2)->rank() == v) {
                                 if (QString((*it2)->name()) == "Diamonds Eight") {
                                     kdDebug(11111) << i << " " << j << endl;
                                 }
@@ -959,9 +979,8 @@ void Dealer::openGame(QDomDocument &doc)
         takeState(); // copying it again
         emit undoPossible(undoList.count() > 1);
     }
-    
-    emit setMoves( dealer.attribute("moves").toInt() );
-        
+
+    emit updateMoves();
     takeState();
 }
 
@@ -972,8 +991,7 @@ void Dealer::undo()
     if (undoList.count() > 1) {
         undoList.removeLast(); // the current state
         setState(undoList.take(undoList.count() - 1));
-        --moves;
-        emit setMoves( moves );
+        emit updateMoves();
         takeState(); // copying it again
         emit undoPossible(undoList.count() > 1);
     }
@@ -1006,7 +1024,8 @@ void Dealer::setWaiting(bool w)
     kdDebug(11111) << "setWaiting " << w << " " << _waiting << endl;
 }
 
-void Dealer::setAutoDropEnabled(bool a) {
+void Dealer::setAutoDropEnabled(bool a)
+{
     _autodrop = a;
     QTimer::singleShot(TIME_BETWEEN_MOVES, this, SLOT(startAutoDrop()));
 }
@@ -1043,7 +1062,7 @@ bool Dealer::startAutoDrop()
             t->source()->moveCards(cards, mh->pile());
             t->move(x, y);
             kdDebug(11111) << "autodrop " << t->name() << endl;
-            t->animatedMove(int(t->source()->x()), int(t->source()->y()), int(t->z()), STEPS_AUTODROP);
+            t->moveTo(int(t->source()->x()), int(t->source()->y()), int(t->z()), STEPS_AUTODROP);
             connect(t, SIGNAL(stoped(Card*)), SLOT(waitForAutoDrop(Card*)));
             return true;
         }
@@ -1169,7 +1188,7 @@ void Dealer::won()
             p.moveTopLeft(QPoint(x, y));
         } while (can.intersects(p));
 
-	(*it).ptr->animatedMove( x, y, 0, STEPS_WON);
+	(*it).ptr->moveTo( x, y, 0, STEPS_WON);
     }
 
     bool demo = demoActive();
@@ -1249,7 +1268,7 @@ void Dealer::demo() {
             int x2 = int(t->realX());
             int y2 = int(t->realY());
             t->move(x1, y1);
-            t->animatedMove(x2, y2, int(t->z()), STEPS_DEMO);
+            t->moveTo(x2, y2, int(t->z()), STEPS_DEMO);
         }
 
         delete [] oldcoords;
@@ -1398,18 +1417,32 @@ void Dealer::wheelEvent( QWheelEvent *e )
     }
 }
 
+void Dealer::countGame()
+{
+    if ( !_gameRecorded ) {
+        kdDebug(11111) << "counting game as played." << endl;
+        KConfig *config = kapp->config();
+        KConfigGroupSaver kcs(config, scores_group);
+        unsigned int Total = config->readUnsignedNumEntry(QString("total%1").arg(_id),0);
+        ++Total;
+        config->writeEntry(QString("total%1").arg(_id),Total);
+        _gameRecorded = true;
+    }
+}
 
 void Dealer::countLoss()
 {
-	 // update score
-    KConfig *config = kapp->config();
-    KConfigGroupSaver kcs(config, scores_group);
-	 unsigned int n = config->readUnsignedNumEntry(QString("loosestreak%1").arg(_id),0) + 1;
-	 config->writeEntry(QString("loosestreak%1").arg(_id),n);
-	 unsigned int m = config->readUnsignedNumEntry(QString("maxloosestreak%1").arg(_id),0);
-	 if (n>m)
-		 config->writeEntry(QString("maxloosestreak%1").arg(_id),n);
-	 config->writeEntry(QString("winstreak%1").arg(_id),0);
+    if ( _gameRecorded ) {
+        // update score
+        KConfig *config = kapp->config();
+        KConfigGroupSaver kcs(config, scores_group);
+        unsigned int n = config->readUnsignedNumEntry(QString("loosestreak%1").arg(_id),0) + 1;
+        config->writeEntry(QString("loosestreak%1").arg(_id),n);
+        unsigned int m = config->readUnsignedNumEntry(QString("maxloosestreak%1").arg(_id),0);
+        if (n>m)
+            config->writeEntry(QString("maxloosestreak%1").arg(_id),n);
+        config->writeEntry(QString("winstreak%1").arg(_id),0);
+    }
 }
 
 #include "dealer.moc"
