@@ -15,7 +15,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -143,7 +143,7 @@ bool KSameWidget::confirmAbort() {
 	return stone->isGameover() ||
 		stone->isOriginalBoard() ||
 		(KMessageBox::questionYesNo(this, i18n("Do you want to resign?"),
-									i18n("New Game")) == KMessageBox::Yes);
+									i18n("New Game"),i18n("Resign"),KStdGuiItem::cancel()) == KMessageBox::Yes);
 }
 
 void KSameWidget::m_new() {
