@@ -6,11 +6,12 @@
 #include <qhbox.h>
 
 #include <kgameprogress.h>
+#include <kdemacros.h>
 
 #include "base/board.h"
 
 /*****************************************************************************/
-class ShowNextPiece : public FixedCanvasView
+class KDE_EXPORT ShowNextPiece : public FixedCanvasView
 {
  Q_OBJECT
  public:
@@ -18,7 +19,7 @@ class ShowNextPiece : public FixedCanvasView
 };
 
 /*****************************************************************************/
-class Shadow : public QWidget
+class KDE_EXPORT Shadow : public QWidget
 {
  Q_OBJECT
  public:
@@ -39,7 +40,7 @@ class Shadow : public QWidget
 /*****************************************************************************/
 class Led;
 
-class GiftPool : public QHBox
+class KDE_EXPORT GiftPool : public QHBox
 {
  Q_OBJECT
  public:
@@ -64,7 +65,7 @@ class GiftPool : public QHBox
 
 
 /*****************************************************************************/
-class PlayerProgress : public KGameProgress
+class KDE_EXPORT PlayerProgress : public KGameProgress
 {
   Q_OBJECT
 public:
